@@ -41,7 +41,9 @@
 
 (load (expand-file-name "f" f-test/root-path) 'noerror 'nomessage)
 
-(require 'ert)
+(require 'ert-async)
+(unless (require 'ert nil t)
+  (require 'ert (expand-file-name "ert" f-test/vendor-path)))
 
 (provide 'f-init)
 
